<?php
/** Buginese (ᨅᨔ ᨕᨘᨁᨗ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ezagren
 * @author Kurniasan
 */

$fallback = "id";

$messages = array(
# Dates
'sunday'        => "Āha'",
'monday'        => 'Asenéŋ',
'tuesday'       => 'Salasa',
'wednesday'     => 'Araba',
'thursday'      => "Kamisi'",
'friday'        => 'Jumā',
'saturday'      => 'Sattu',
'sun'           => 'Āha',
'mon'           => 'Ase',
'tue'           => 'Sal',
'wed'           => 'Ara',
'thu'           => 'Kam',
'fri'           => 'Jum',
'sat'           => 'Sat',
'january'       => 'Januari',
'february'      => 'Fébruari',
'march'         => "Maré'",
'april'         => 'April',
'may_long'      => 'Méi',
'june'          => 'Juni',
'july'          => 'Juli',
'august'        => "Ogoso'",
'september'     => 'September',
'october'       => 'Oktober',
'november'      => 'November',
'december'      => 'Désémber',
'january-gen'   => 'Januari',
'february-gen'  => 'Fébruari',
'march-gen'     => "Maré'",
'april-gen'     => 'April',
'may-gen'       => 'Méi',
'june-gen'      => 'Juni',
'july-gen'      => 'Juli',
'august-gen'    => "Ogoso'",
'september-gen' => 'September',
'october-gen'   => 'Oktober',
'november-gen'  => 'November',
'december-gen'  => 'Désémber',

# Categories related messages
'category_header' => 'Leppa rilaleŋ kategori "$1"',
'subcategories'   => 'Subkategori',

'about'      => 'Atajangeng',
'article'    => 'Lontara',
'cancel'     => 'Rusa',
'mypage'     => "Leppana iya'",
'mytalk'     => 'Bicarana iyya',
'anontalk'   => 'Bicarana IP édé',
'navigation' => 'Navigasi',
'and'        => '&#32;na',

# Cologne Blue skin
'qbfind'         => 'Assapparang',
'qbbrowse'       => 'Berowoso',
'qbedit'         => 'Padécéŋ',
'qbpageoptions'  => 'Édé leppa',
'qbpageinfo'     => 'Konteks',
'qbmyoptions'    => "Leppana iya'",
'qbspecialpages' => 'Leppa spésiala',
'faq'            => 'FAQ',
'faqpage'        => 'Project:FAQ',

# Vector skin
'vector-action-move'     => "Paléccé'",
'vector-view-create'     => 'Ebbu',
'vector-view-edit'       => 'Padéccéng',
'vector-view-view'       => 'Baca',
'vector-view-viewsource' => 'Ita sumber',

'errorpagetitle'   => 'Asalaŋ',
'returnto'         => 'Lisu ri $1.',
'tagline'          => 'Polé {{SITENAME}}',
'help'             => 'Paŋinriŋ',
'search'           => 'Assapparaŋ',
'searchbutton'     => 'Sappa',
'go'               => 'Lao',
'searcharticle'    => 'Lao',
'history'          => 'Versi riolo leppaë',
'history_short'    => 'versi riolo',
'permalink'        => 'Pranala permanen',
'edit'             => 'Padécéŋ',
'create'           => 'Ebbu',
'editthispage'     => 'Padécéŋiki iyé leppa',
'create-this-page' => 'Ebbuiki leppa iyé',
'delete'           => 'Peddé',
'deletethispage'   => 'Peddé iyé leppa',
'protect'          => 'Accalinruŋi',
'protect_change'   => 'pinra',
'protectthispage'  => 'Accalinruŋi leppa iyyé',
'unprotect'        => 'Téccalinruŋi',
'newpage'          => 'Leppa baru',
'talkpage'         => 'Bicara iyé leppa',
'talkpagelinktext' => 'Bicara',
'specialpage'      => 'Leppa spésiala',
'personaltools'    => 'Tool sialé-alé',
'articlepage'      => 'Ita lontara',
'talk'             => 'Bicara',
'toolbox'          => 'Toolbox',
'userpage'         => 'Ita leppa papaké',
'projectpage'      => 'Ita leppa proyék',
'imagepage'        => 'Ita leppa rapaŋ',
'mediawikipage'    => 'Ita leppa méséje',
'templatepage'     => 'Ita leppa templata',
'viewhelppage'     => 'Ita leppa panginriŋ',
'categorypage'     => 'Ita leppa kategori',
'viewtalkpage'     => 'Ita leppa bicara',
'redirectedfrom'   => '(Riredirect polé $1)',
'redirectpagesub'  => 'Leppa redirect',
'jumpto'           => 'Luppe lao:',
'jumptosearch'     => 'sappa',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Tentang {{SITENAME}}',
'currentevents'        => 'Accanjingeŋ kokkoro',
'currentevents-url'    => 'Project:Accanjingeŋ kokkoro',
'disclaimers'          => 'Diseklaima',
'edithelp'             => 'Paŋinriŋ mapadécéŋ',
'edithelppage'         => 'Help:Mapadécéŋ',
'helppage'             => 'Help:Lise',
'mainpage'             => 'Leppa Indoë',
'mainpage-description' => 'Leppa Indoë',
'portal'               => 'Portal komunitas',

'newmessageslink' => 'pappaseŋ baru',
'editsection'     => 'padécéŋ',
'editold'         => 'padécéŋ',
'viewsourceold'   => 'ita sumber',
'editlink'        => 'padécéŋ',
'viewsourcelink'  => 'ita sumber',
'editsectionhint' => 'Padécéŋ kajuru: $1',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Leppa',
'nstab-user'      => 'Leppa papaké',
'nstab-media'     => 'Leppa média',
'nstab-special'   => 'Leppa spésiala',
'nstab-project'   => 'Proyek',
'nstab-image'     => 'Rapang',
'nstab-mediawiki' => 'Pappaseŋ',
'nstab-template'  => 'Templata',
'nstab-help'      => 'Paŋinriŋ',
'nstab-category'  => 'Kategori',

# Main script and global functions
'nosuchspecialpage' => "Iyaro leppa spésiala dé'na eŋka",

# General errors
'error'               => 'Éro',
'databaseerror'       => 'Éro databése',
'readonly'            => 'Databése rikonci',
'missingarticle-diff' => '(Beda: $1, $2)',
'internalerror'       => 'Éro internal',
'internalerror_info'  => 'Éro internal: $1',
'badtitle'            => 'Judul dek essa',
'viewsource'          => 'Ita sumber',
'viewsourcefor'       => 'polé $1',

# Virus scanner
'virus-unknownscanner' => "Antivirus dé' riisseŋ:",

# Login and logout pages
'yourname'                => 'Aseŋ papaké:',
'yourpassword'            => 'Adacili:',
'login'                   => 'log attama',
'nav-login-createaccount' => 'Log attama / ebbu akun',
'userlogin'               => 'Log attama / ebbu akun',
'logout'                  => 'Log essu',
'userlogout'              => 'Log essu',
'notloggedin'             => 'Déppa log attama',
'nologin'                 => "Dé' gaga akaun? '''$1'''.",
'nologinlink'             => 'Ebbu akun',
'createaccount'           => 'Ebbu akun',
'gotaccount'              => "Purani eŋka akun? '''$1'''.",
'gotaccountlink'          => 'Log attama',
'loginerror'              => 'Éro log attama',
'mailmypassword'          => 'E-mail adacili baru',

# Change password dialog
'oldpassword' => 'Pasewodo matoa:',

# Edit page toolbar
'bold_tip'    => 'Teks maumpek',
'italic_tip'  => 'Teks Italik',
'extlink_tip' => 'Link risaliweŋ (jangan lupa awalan http:// )',

# Edit pages
'savearticle'      => 'Taro leppa',
'preview'          => 'Pribiu',
'showpreview'      => 'Ita pribiu',
'showlivepreview'  => 'Pribiu live',
'showdiff'         => 'Mita perubahan',
'summary-preview'  => 'Pribiu summary:',
'blockedtitle'     => 'Papaké riblok',
'accmailtitle'     => 'Ada sandi ni riantarak.',
'accmailtext'      => 'Ada sandi "$1" riantarak ri $2.',
'anontalkpagetext' => "----''Ini adalah halaman diskusi untuk pengguna anonim yang belum membuat rekening atau tidak menggunakannya. Karena tidak membuat rekening, kami terpaksa memakai alamat IP untuk mengenalinya. Alamat IP seperti ini dapat dipakai oleh beberapa pengguna yang berbeda. Jika Anda adalah pengguna anonim dan merasa mendapatkan komentar-komentar yang tidak berkaitan dengan anda, kami anjurkan untuk [[Special:UserLogin|membuat rekening atau masuk log]] untuk menghindari kerancuan dengan pengguna anonim lain.''",
'editing'          => 'Mapadécéŋ $1',

# History pages
'previousrevision'    => '←Revisi riolo',
'currentrevisionlink' => 'Revisi tannapa',
'page_first'          => 'séuwani',
'histfirst'           => 'Poŋ loa',
'histlast'            => 'Poŋ nappa',
'historysize'         => '($1 {{PLURAL:$1|bita|bita}})',
'historyempty'        => '(kapa)',

# Revision feed
'history-feed-item-nocomment' => '$1 ri $2',

# Revision deletion
'rev-deleted-comment'    => '(komentar ripeddé)',
'rev-deleted-user'       => '(ripeddéni aseŋna papakeë)',
'rev-deleted-event'      => '(log gau ripeddéni)',
'rev-delundel'           => "pakitaï/tapo'",
'revdelete-selected'     => "'''{{PLURAL:$2|Revisi|Revisi-revisi}} ripiléna [[$1]]ë:'''",
'logdelete-selected'     => "'''{{PLURAL:$1|Log|Log-log}} ripilé:'''",
'revdelete-hide-text'    => 'Tapoïki text revisië',
'revdelete-hide-comment' => 'Tapo komentar mapadecéŋ',
'revdelete-hide-user'    => 'Tapo aseŋ papakéna/IPna papadéceŋë',
'revdelete-log'          => 'Saba:',
'revdelete-content'      => 'lise',
'revdelete-uname'        => 'aseŋ papaké',
'revdelete-hid'          => 'tapo $1',

# Diffs
'editundo' => 'undo',

# Search results
'searchsubtitle'        => "Masappa iko '''[[:$1]]'''",
'searchsubtitleinvalid' => "Massappa iko '''$1'''",
'viewprevnext'          => 'Ita ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'        => 'Help:Lise',
'search-result-size'    => '$1 ({{PLURAL:$2|1 ada|$2 ada}})',
'search-redirect'       => '(redirect $1)',

# Quickbar
'qbsettings-none' => 'Dégaga',

# Preferences page
'mypreferences'     => 'Bérékkeŋeŋna iyya',
'prefsnologin'      => "Déppa ma'log attama'",
'prefs-watchlist'   => 'Watchlist',
'prefs-misc'        => 'Misc',
'saveprefs'         => 'Taro',
'prefs-editing'     => 'Mapadécéŋ',
'searchresultshead' => 'Masappa',
'youremail'         => 'E-mail:',
'username'          => 'Aseŋ papaké:',
'uid'               => 'ID papaké:',
'email'             => 'E-mail',

# Groups
'group-sysop' => 'Puŋgawa',
'group-all'   => '(sininna)',

'group-user-member'  => 'Pappaké',
'group-sysop-member' => 'Puŋgawa',

'grouppage-user'  => '{{ns:project}}:Pappaké',
'grouppage-sysop' => '{{ns:project}}:Puŋgawa',

# Rights
'right-read' => 'Mabbaca leppa',
'right-edit' => 'Mappadécéŋi leppa',

# Recent changes
'recentchanges'   => 'Pappakinra tanappa',
'rcshowhidebots'  => '$1 bot',
'rcshowhideliu'   => "$1 papaké mattama' log",
'rcshowhideanons' => '$1 papaké anon',
'diff'            => 'beda',
'hide'            => 'Tapok',
'minoreditletter' => 'k',
'newpageletter'   => 'B',
'boteditletter'   => 'b',

# Recent changes linked
'recentchangeslinked'         => 'Pappakapinra terkait',
'recentchangeslinked-feed'    => 'Pappakapinra terkait',
'recentchangeslinked-toolbox' => 'Pappakapinra terkait',

# Upload
'upload'    => 'Lureng berkas',
'uploadbtn' => 'Lureng berkas',

# Special:ListFiles
'listfiles_name' => 'Aseŋ',

# File description page
'file-anchor-link'    => 'Rapang',
'filehist-user'       => 'Papaké',
'filehist-dimensions' => 'Dimensi',
'imagelinks'          => 'Liŋke',

# File reversion
'filerevert-backlink' => '← $1',

# File deletion
'filedelete'             => 'Mapeddé $1',
'filedelete-backlink'    => '← $1',
'filedelete-legend'      => 'Mapeddé berkas',
'filedelete-intro'       => "Iko purani mapeddé '''[[Media:$1|$1]]'''.",
'filedelete-submit'      => 'Peddé',
'filedelete-success'     => "'''$1''' purani ripeddé.",
'filedelete-success-old' => "Berkas '''[[Media:$1|$1]]''' versi $3, $2 purani ripeddé.",
'filedelete-nofile'      => "'''$1''' dé'na eŋka.",

# MIME search
'mimesearch' => 'Assapparaŋ MIME',
'mimetype'   => 'Tipe MIME:',
'download'   => 'unduh',

# Random page
'randompage'         => 'Leppa random',
'randompage-nopages' => 'Degaga leppa rilaleŋ iyyé namespaceë.',

# Statistics
'statistics-articles' => 'Leppa liseë',
'statistics-pages'    => 'Leppaë',
'statistics-files'    => 'File-file nalise menré',

# Miscellaneous special pages
'ancientpages' => 'Leppa talloa',
'move'         => 'Paleccé',
'movethispage' => 'Paleccé leppa iyyé',

# Special:Log
'specialloguserlabel' => 'Papaké:',
'log'                 => 'Log',
'all-logs-page'       => 'Maneŋ log',

# Special:AllPages
'allpages'          => 'Maneng halamang',
'alphaindexline'    => '$1 ri $2',
'allpagesfrom'      => 'Mappaitang halamang-halamang rimulai:',
'allarticles'       => 'Sininna leppa',
'allinnamespace'    => 'Maneŋ leppa (namespace $1)',
'allnotinnamespace' => 'Maneŋ leppa (tania rilaleŋ namespace $1)',
'allpagesnext'      => 'Selanjutnya',
'allpagessubmit'    => 'Lanre',
'allpagesprefix'    => 'Mappaitang halamang-halamang éngkalinga awang:',

# Special:Categories
'categories' => 'Maneŋ kategori',

# Watchlist
'addedwatchtext' => "Halamang \"[[:\$1]]\" ni ritamba ri ida [[Special:Watchlist|watchlist]].
Halamang bicara éréngé gabungan halamang bicara pada wettu depan didaftarkan koe,
éréngé halamang akan wessi '''umpek''' ri [[Special:RecentChanges|daftar pinra tanappa]] barak lebih lemmak ita.

Apak ida ronnak mappedde halamang édé ri daftar jagaan, klik \"Mangedda jaga\" pada kolom ri sedde.",
'watch'          => 'Ampi',
'unwatch'        => 'Tenriampi',

# Delete
'actioncomplete' => 'Proses makkapo',
'dellogpage'     => 'Log peddé-peddé',

# Protect
'prot_1movedto2' => '[[$1]] ésuk ri [[$2]]',

# Namespace form on various pages
'blanknamespace' => '(Utama)',

'sp-contributions-talk' => 'Bicara',

# What links here
'whatlinkshere'          => 'Pranala ri leppa iyéwé',
'whatlinkshere-page'     => 'Leppa:',
'whatlinkshere-backlink' => '← $1',
'whatlinkshere-links'    => '← liŋke',

# Block/unblock
'ipblocklist-submit' => 'Sappa',
'blocklink'          => 'blok',
'contribslink'       => 'kontrib',

# Move page
'articleexists'             => 'Leppa béla ida pile ni ujuk, a dek essa.
Silakan pile aseng laing.',
'1movedto2'                 => '[[$1]] léccé lao [[$2]]',
'1movedto2_redir'           => '[[$1]] rileccé lao ri[[$2]] paké redirect',
'movelogpage'               => 'Log leccé',
'movereason'                => 'Saba:',
'delete_and_move'           => 'Peddé nappa paleccé',
'delete_and_move_text'      => '==Mapeddé riperelu==
Leppa destinasi "[[:$1]]" purani eŋka.
Eloko peddéï supaya weddiŋi mapalecé?',
'delete_and_move_confirm'   => "Iyé', peddé iyaro leppa",
'delete_and_move_reason'    => 'Ripeddé supaya weddiŋi mapalecé',
'immobile-source-namespace' => 'Leppa-leppa rilaleŋna namespace "$1"ë de\'na ullé ripaleccé',
'immobile-source-page'      => "Iyyedé leppaë de'na ullé ripaleccé.",

# Namespace 8 related
'allmessages'        => 'Maneng pappaseng',
'allmessagesname'    => 'Aseng',
'allmessagesdefault' => 'Teks totok',
'allmessagescurrent' => 'Teks kokkoro',

# Tooltip help for the actions
'tooltip-pt-userpage'      => "Leppa papaké iya'",
'tooltip-pt-mytalk'        => "Leppa bicara iya'",
'tooltip-pt-preferences'   => "Preferencena iya'",
'tooltip-pt-logout'        => 'Log maessu',
'tooltip-ca-talk'          => 'Pabicarana iyé leppa',
'tooltip-ca-move'          => 'Paléccé leppa édé',
'tooltip-search'           => 'Sappa ri {{SITENAME}}',
'tooltip-search-go'        => 'Lao ri leppa aseŋna pappada iyyé rekko eŋkaï',
'tooltip-n-mainpage'       => 'Lao ri Leppa Indoë',
'tooltip-ca-nstab-special' => "Iyanaéwé séuwa leppa spésiala', dé'na idi' ullé padécéŋiki",

# Attribution
'anonymous' => 'Pabbuak anonim {{SITENAME}}',

# Media information
'imagemaxsize' => 'Gangkai rapang pada keterangan rapang ri halamang hingga:',

# Special:NewFiles
'ilsubmit' => 'Sappa',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'maneŋ',
'namespacesall' => 'maneŋ',
'monthsall'     => 'maneŋ',

# Multipage image navigation
'imgmultigo'   => 'Lao!',
'imgmultigoto' => 'Lao ri leppa $1',

# Table pager
'ascending_abbrev'         => 'énré',
'descending_abbrev'        => 'no',
'table_pager_first'        => 'Leppa séuwani',
'table_pager_limit_submit' => 'Lao',

# Auto-summaries
'autosumm-replace' => "Masullé leppaë lao '$1'",
'autosumm-new'     => "Leppa baru: '$1'",

# Size units
'size-bytes'     => '$1 B',
'size-kilobytes' => '$1 KB',
'size-megabytes' => '$1 MB',
'size-gigabytes' => '$1 GB',

# Live preview
'livepreview-loading' => 'Mallise…',
'livepreview-ready'   => 'Mallise… Sokkuni!',

# Special:Version
'version-specialpages' => 'Leppa spésiala',

# Special:SpecialPages
'specialpages'                 => 'Leppa spésiala',
'specialpages-note'            => '----
* Leppa spésiala normal
* <strong class="mw-specialpagerestricted">Leppa spésiala terbatas</strong>',
'specialpages-group-other'     => 'Leppa spésiala laiŋë',
'specialpages-group-login'     => 'Log attama / mendaftar',
'specialpages-group-changes'   => 'Pinrana tanappaë sibawa logeë',
'specialpages-group-users'     => 'Papaké sibawa hak-hak',
'specialpages-group-pages'     => 'Sininna leppaë',
'specialpages-group-pagetools' => 'Tool leppaë',
'specialpages-group-wiki'      => 'Data sibawa tool wiki',
'specialpages-group-spam'      => 'Tool spam',

# Special:BlankPage
'blankpage' => 'Leppa kosoŋë',

);
